==> derby-0.0.10.tgz: package/examples/sink/sink.js <==
var ctxFor, get, pages, ready, sink, view, _ref;
_ref = sink = require('derby').createApp(module), get = _ref.get, view = _ref.view, ready = _ref.ready;
pages = [
  {
    name: 'home',
    text: 'Home',
    url: '/'
  }, {
    name: 'liveCss',
    text: 'Live CSS',
    url: '/live-css'
  }, {
    name: 'submit',
    text: 'Submit form',
    url: '/submit'
  }, {
    name: 'back',
    text: 'Back redirect',
    url: '/back'
  }, {
    name: 'error',
    text: 'Error test',
    url: '/error'
  }
];
ctxFor = function(name, ctx) {
  var i, last, page;
  if (ctx == null) {
    ctx = {};
  }
  ctx[name + 'Visible'] = true;
  last = pages.length - 1;
  ctx.pages = (function() {
    var _len, _results;
    _results = [];
    for (i = 0, _len = pages.length; i < _len; i++) {
      page = pages[i];
      page = Object.create(page);
      if (page.name === name) {
        page.current = true;
        ctx.title = page.text;
      }
      page.last = i === last;
      _results.push(page);
    }
    return _results;
  })();
  return ctx;
};
get('/', function(page) {
  return page.render(ctxFor('home'));
});
get('/live-css', function(page, model) {
  return model.subscribe('liveCss', function() {
    console.log(model.get('liveCss.styles') != null);
    model.setNull('liveCss.styles', [
      {
        prop: 'color',
        value: '#c00',
        active: true
      }, {
        prop: 'font-weight',
        value: 'bold',
        active: true
      }, {
        prop: 'font-size',
        value: '18px',
        active: false
      }
    ]);
    model.setNull('liveCss.outputText', 'Edit this text...');
    console.log(model.get('liveCss.outputText'), model.get('liveCss.styles'));
    return page.render(ctxFor('liveCss'));
  });
});
['get', 'post', 'put', 'del'].forEach(function(method) {
  return sink[method]('/submit', function(page, model, _arg) {
    var args, body, query;
    body = _arg.body, query = _arg.query;
    args = JSON.stringify({
      method: method,
      body: body,
      query: query
    }, null, '  ');
    return page.render(ctxFor('submit', {
      args: args
    }));
  });
});
get('/error', function() {
  throw new Error(500);
});
get('/back', function(page) {
  return page.redirect('back');
});
view.make('Title', 'Derby demo: {{title}}');
view.make('Head', '<style>\n  p{margin:0;padding:0}\n  body{margin:10px}\n  body,select{font:13px/normal arial,sans-serif}\n  ins{text-decoration:none}\n  .css{margin-left:10px}\n</style>');
view.make('Body', '<p>\n{{#pages}}\n  {{#current}}\n    <b>{{text}}</b>{{^last}} | {{/}}\n  {{^}}\n    <a href={{url}}>{{text}}</a>{{^last}} | {{/}}\n  {{/}}\n{{/}}\n<hr>\n{{#homeVisible}}{{> home}}{{/}}\n{{#liveCssVisible}}{{> liveCss}}{{/}}\n{{#submitVisible}}{{> submit}}{{/}}');
view.make('home', '<h1>Welcome!</h1>\n<p>This is a collection of random demos. Check \'em out! <a href=#jump>Test jump link</a>\n<p style=margin-top:1000px>\n<a name=jump>Jumped!</a>');
view.make('liveCss', '<select multiple><optgroup label="CSS properties">\n  ((#liveCss.styles))<option selected=((.active))>((.prop))((/))\n</select>\n<div>\n  ((#liveCss.styles))\n    <p><input type=checkbox checked=((.active))> \n    <input value=((.prop)) disabled=!((.active))> \n    <input value=((.value)) disabled=!((.active))>\n  ((/))\n</div>\n<button x-bind=click:addStyle>Add</button>\n<h3>Currently applied:</h3>\n<p>{\n  <p class=css>((#liveCss.styles :style))((> cssProperty))((#:style.active))<br>((/))((/))\n<p>}\n<h3>Output:</h3>\n<p style="((liveCss.styles :style > cssProperty))" contenteditable>\n  (((liveCss.outputText)))\n</p>');
view.make('cssProperty', '((#:style.active))((:style.prop)): ((:style.value));((/))');
view.make('submit', '<form action=submit method=post>\n  <input type=hidden name=_method value=put>\n  <p><label>Name: <input type=text name=user[name]></label>\n  <p><label>Email: <input type=text name=user[email]></label>\n  <p><input type=submit>\n</form>\n<h3>Arguments:</h3>\n<pre><code>{{args}}</code></pre>');
ready(function(model) {
  return exports.addStyle = function() {
    return model.push('liveCss.styles', {});
  };
});

==> derby-0.1.0.tgz: package/examples/sink/sink.js <==
var ctxFor, get, pages, ready, sink, view, _ref;
_ref = sink = require('derby').createApp(module), get = _ref.get, view = _ref.view, ready = _ref.ready;
pages = [
  {
    name: 'home',
    text: 'Home',
    url: '/'
  }, {
    name: 'liveCss',
    text: 'Live CSS',
    url: '/live-css'
  }, {
    name: 'submit',
    text: 'Submit form',
    url: '/submit'
  }, {
    name: 'back',
    text: 'Back redirect',
    url: '/back'
  }, {
    name: 'error',
    text: 'Error test',
    url: '/error'
  }
];
ctxFor = function(name, ctx) {
  var i, last, page;
  if (ctx == null) {
    ctx = {};
  }
  ctx[name + 'Visible'] = true;
  last = pages.length - 1;
  ctx.pages = (function() {
    var _len, _results;
    _results = [];
    for (i = 0, _len = pages.length; i < _len; i++) {
      page = pages[i];
      page = Object.create(page);
      if (page.name === name) {
        page.current = true;
        ctx.title = page.text;
      }
      page.last = i === last;
      _results.push(page);
    }
    return _results;
  })();
  return ctx;
};
get('/', function(page) {
  return page.render(ctxFor('home'));
});
get('/live-css', function(page, model) {
  return model.subscribe('liveCss', function() {
    model.setNull('liveCss.styles', [
      {
        prop: 'color',
        value: '#c00',
        active: true
      }, {
        prop: 'font-weight',
        value: 'bold',
        active: true
      }, {
        prop: 'font-size',
        value: '18px',
        active: false
      }
    ]);
    model.setNull('liveCss.outputText', 'Edit this text...');
    return page.render(ctxFor('liveCss'));
  });
});
['get', 'post', 'put', 'del'].forEach(function(method) {
  return sink[method]('/submit', function(page, model, _arg) {
    var args, body, query;
    body = _arg.body, query = _arg.query;
    args = JSON.stringify({
      method: method,
      body: body,
      query: query
    }, null, '  ');
    return page.render(ctxFor('submit', {
      args: args
    }));
  });
});
get('/error', function() {
  throw new Error(500);
});
get('/back', function(page) {
  return page.redirect('back');
});
view.make('Title', 'Derby demo: {{title}}');
view.make('Head', '<style>\n  p{margin:0;padding:0}\n  body{margin:10px}\n  body,select{font:13px/normal arial,sans-serif}\n  ins{text-decoration:none}\n  .css{margin-left:10px}\n</style>');
view.make('Body', '<p>\n{{#pages}}\n  {{#current}}\n    <b>{{text}}</b>{{^last}} | {{/}}\n  {{^}}\n    <a href={{url}}>{{text}}</a>{{^last}} | {{/}}\n  {{/}}\n{{/}}\n<hr>\n{{#homeVisible}}{{> home}}{{/}}\n{{#liveCssVisible}}{{> liveCss}}{{/}}\n{{#submitVisible}}{{> submit}}{{/}}');
view.make('home', '<h1>Welcome!</h1>\n<p>This is a collection of random demos. Check \'em out! <a href=#jump>Test jump link</a>\n<p style=margin-top:1000px>\n<a name=jump>Jumped!</a>');
view.make('liveCss', '<select multiple><optgroup label="CSS properties">\n  ((#liveCss.styles))<option selected=((.active))>((.prop))((/))\n</select>\n<div>\n  ((#liveCss.styles))\n    <p><input type=checkbox checked=((.active))> \n    <input value=((.prop)) disabled=!((.active))> \n    <input value=((.value)) disabled=!((.active))> \n    <button x-bind=click:deleteStyle>Delete</button>\n  ((/))\n</div>\n<button x-bind=click:addStyle>Add</button>\n<h3>Currently applied:</h3>\n<p>{\n  <div>\n    ((#liveCss.styles :style))\n      <p class=css x-displayed=((:style.active))>((> cssProperty))</p>\n    ((/))\n  </div>\n<p>}\n<h3>Output:</h3>\n<p style="((liveCss.styles :style > cssProperty))" contenteditable>\n  (((liveCss.outputText)))\n</p>');
view.make('cssProperty', '((#:style.active))((:style.prop)): ((:style.value));((/))');
view.make('submit', '<form action=submit method=post>\n  <input type=hidden name=_method value=put>\n  <p><label>Name: <input type=text name=user[name]></label>\n  <p><label>Email: <input type=text name=user[email]></label>\n  <p><input type=submit>\n</form>\n<h3>Arguments:</h3>\n<pre><code>{{args}}</code></pre>');
ready(function(model) {
  exports.addStyle = function() {
    return model.push('liveCss.styles', {});
  };
  return exports.deleteStyle = function(e) {
    var child, i, item, _len, _ref2;
    item = e.target.parentNode;
    _ref2 = item.parentNode.childNodes;
    for (i = 0, _len = _ref2.length; i < _len; i++) {
      child = _ref2[i];
      if (child === item) {
        return model.remove('liveCss.styles', i);
      }
    }
  };
});
